==> tinyerp-3.0.tar.gz: 3.0/server/bin/addons/mrp/wizard/wizard_procurement.py <==
##############################################################################
#
# Copyright (c) 2005 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id$
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import netsvc
import sql_db
import time
from mx import DateTime
from osv import osv

parameter_form = '''<?xml version="1.0"?>
<form title="Parameters" colspan="4">
	<separator string="Time (days)" colspan="4"/>
	<field name="po_lead"/>
	<field name="picking_lead"/>
	<field name="schedule_cycle"/>
	<field name="po_cycle"/>
	<field name="security_lead"/>
	<separator string="Control" colspan="4"/>
	<field name="user_id"/>
</form>'''

parameter_fields = {
	'schedule_cycle': {'string':'Scheduler Cycle', 'type':'float', 'required':True},
	'po_cycle': {'string':'PO Cycle', 'type':'float', 'required':True},
	'po_lead': {'string':'PO Lead Time', 'type':'float', 'required':True},
	'security_lead': {'string':'Security Days', 'type':'float', 'required':True},
	'picking_lead': {'string':'Picking Lead Time', 'type':'float', 'required':True},
	'user_id': {'string':'Send Result To', 'type':'many2one', 'relation':'res.users'},
}

def _procure_confirm(self, uid, datas):
	cr = sql_db.db.cursor()

	wf_service = netsvc.LocalService("workflow")
	po_time = (datas['form']['po_cycle'] or 0.0) + (datas['form']['po_lead'] or 0.0)
	maxdate = DateTime.now() + DateTime.RelativeDateTime(days=(datas['form']['schedule_cycle'] or 0.0) + (datas['form']['security_lead'] or 0.0))
	offset = 0
	ids = [1]
	while len(ids):
		cr.execute('select id from mrp_procurement where state=%s and procure_method=%s order by id limit 500 offset %d', ('confirmed','make_to_order',offset))
		ids = map(lambda x:x[0], cr.fetchall())
		for proc in osv.osv_pools.get('mrp.procurement').browse(cr, uid, ids):
			if proc.product_id.supply_method=='produce':
				wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
			else:
				if (maxdate + DateTime.RelativeDateTime(days=(proc.product_id.seller_delay or 0 + po_time))).strftime('%Y-%m-%d')>=proc.date_planned:
					wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
				else:
					offset+=1
		cr.commit()

	offset = 0
	ids = [1]
	while len(ids):
		ids = osv.osv_pools.get('mrp.procurement').search(cr, uid, [('state','=','confirmed'),('procure_method','=','make_to_stock')], offset=offset)
		for proc in osv.osv_pools.get('mrp.procurement').browse(cr, uid, ids):
			if (maxdate + DateTime.RelativeDateTime(days=datas['form']['picking_lead'])).strftime('%Y-%m-%d') >= proc.date_planned:
				wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
			else:
				print 'Procurement will be run later'
		offset += len(ids)
	cr.commit()
	cr.close()
	return {}

def _get_value(self, uid, datas):
	return {}

class procurement_compute(wizard.interface):
	states = {
		'init': {
			'actions': [_get_value],
			'result': {'type': 'form', 'arch':parameter_form, 'fields': parameter_fields, 'state':[('compute','Compute Procurements'), ('end','Cancel')]}
		},
		'compute': {
			'actions': [_procure_confirm],
			'result': {'type': 'state', 'state':'end'}
		},
	}
procurement_compute('mrp.procurement.compute')

==> tinyerp-3.0.1.tar.gz: 3.0.1/server/bin/addons/mrp/wizard/wizard_procurement.py <==
##############################################################################
#
# Copyright (c) 2005 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id$
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import wizard
import netsvc
import sql_db
import time
from mx import DateTime
from osv import osv

import threading

parameter_form = '''<?xml version="1.0"?>
<form title="Parameters" colspan="4">
	<separator string="Time (days)" colspan="4"/>
	<field name="po_lead"/>
	<field name="picking_lead"/>
	<field name="schedule_cycle"/>
	<field name="po_cycle"/>
	<field name="security_lead"/>
	<separator string="Control" colspan="4"/>
	<field name="user_id"/>
</form>'''

parameter_fields = {
	'schedule_cycle': {'string':'Scheduler Cycle', 'type':'float', 'required':True},
	'po_cycle': {'string':'PO Cycle', 'type':'float', 'required':True},
	'po_lead': {'string':'PO Lead Time', 'type':'float', 'required':True},
	'security_lead': {'string':'Security Days', 'type':'float', 'required':True},
	'picking_lead': {'string':'Picking Lead Time', 'type':'float', 'required':True},
	'user_id': {'string':'Send Result To', 'type':'many2one', 'relation':'res.users'},
}

def _procure_confirm(self, uid, datas):
	cr = sql_db.db.cursor()

	wf_service = netsvc.LocalService("workflow")
	po_time = (datas['form']['po_cycle'] or 0.0) + (datas['form']['po_lead'] or 0.0)
	maxdate = DateTime.now() + DateTime.RelativeDateTime(days=(datas['form']['schedule_cycle'] or 0.0) + (datas['form']['security_lead'] or 0.0))
	offset = 0
	ids = [1]
	while len(ids):
		cr.execute('select id from mrp_procurement where state=%s and procure_method=%s order by id limit 500 offset %d', ('confirmed','make_to_order',offset))
		ids = map(lambda x:x[0], cr.fetchall())
		for proc in osv.osv_pools.get('mrp.procurement').browse(cr, uid, ids):
			if proc.product_id.supply_method=='produce':
				wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
			else:
				if (maxdate + DateTime.RelativeDateTime(days=(proc.product_id.seller_delay or 0 + po_time))).strftime('%Y-%m-%d')>=proc.date_planned:
					wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
				else:
					offset+=1
		cr.commit()

	offset = 0
	ids = [1]
	later = False
	while len(ids):
		ids = osv.osv_pools.get('mrp.procurement').search(cr, uid, [('state','=','confirmed'),('procure_method','=','make_to_stock')], offset=offset)
		for proc in osv.osv_pools.get('mrp.procurement').browse(cr, uid, ids):
			if (maxdate + DateTime.RelativeDateTime(days=datas['form']['picking_lead'])).strftime('%Y-%m-%d') >= proc.date_planned:
				wf_service.trg_validate(uid, 'mrp.procurement', proc.id, 'button_check', cr)
			else:
				later = True
		offset += len(ids)

	if 'user_id' in datas['form'] and datas['form']['user_id']:
		request = osv.osv_pools.get('res.request')
		if later:
			summary = 'Procurment calculation done.\nSome procurement will be run later'
		request.create(cr, uid, 
			  {'name' : "End of procurment calculation",
			   'act_from' : datas['form']['user_id'],
			   'act_to' : datas['form']['user_id'],
			   })
	cr.commit()
	cr.close()
	return {}

def _procure_calculation(self, uid, datas):
	threaded_calculation = threading.Thread(target=_procure_confirm, args=(self, uid, datas))
	threaded_calculation.start()
	return {}

def _get_value(self, uid, datas):
	return {}

class procurement_compute(wizard.interface):
	states = {
		'init': {
			'actions': [_get_value],
			'result': {'type': 'form', 'arch':parameter_form, 'fields': parameter_fields, 'state':[('compute','Compute Procurements'), ('end','Cancel')]}
		},
		'compute': {
			'actions': [_procure_calculation],
			'result': {'type': 'state', 'state':'end'}
		},
	}
procurement_compute('mrp.procurement.compute')
